@@ -171,13 +171,13 @@ class CheckRun(github.GithubObject.CompletableGithubObject):
 
     def get_annotations(self):
         """
-        :calls: `GET /repos/:owner/:repo/check-runs/:check_run_id/annotations <https://docs.github.com/en/rest/reference/checks#list-check-run-annotations>`_
+        :calls: `GET /repos/{owner}/{repo}/check-runs/{check_run_id}/annotations <https://docs.github.com/en/rest/reference/checks#list-check-run-annotations>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.CheckRunAnnotation.CheckRunAnnotation`
         """
         return github.PaginatedList.PaginatedList(
             github.CheckRunAnnotation.CheckRunAnnotation,
             self._requester,
-            self.url + "/annotations",
+            f"{self.url}/annotations",
             None,
             headers={"Accept": "application/vnd.github.v3+json"},
         )
@@ -196,7 +196,7 @@ class CheckRun(github.GithubObject.CompletableGithubObject):
         actions=github.GithubObject.NotSet,
     ):
         """
-        :calls: `PATCH /repos/:owner/:repo/check-runs/:check_run_id <https://docs.github.com/en/rest/reference/checks#update-a-check-run>`_
+        :calls: `PATCH /repos/{owner}/{repo}/check-runs/{check_run_id} <https://docs.github.com/en/rest/reference/checks#update-a-check-run>`_
         :param name: string
         :param head_sha: string
         :param details_url: string
@@ -276,7 +276,6 @@ class CheckRun(github.GithubObject.CompletableGithubObject):
         self._name = github.GithubObject.NotSet
         self._node_id = github.GithubObject.NotSet
         self._output = github.GithubObject.NotSet
-        self._output = github.GithubObject.NotSet
         self._pull_requests = github.GithubObject.NotSet
         self._started_at = github.GithubObject.NotSet
         self._status = github.GithubObject.NotSet
