@@ -29,7 +29,7 @@ import github.GithubObject
 
 class Deployment(github.GithubObject.CompletableGithubObject):
     """
-    This class represents Deployments. The reference can be found here https://developer.github.com/v3/repos/deployments
+    This class represents Deployments. The reference can be found here https://docs.github.com/en/rest/reference/repos#deployments
     """
 
     def __repr__(self):
@@ -43,6 +43,14 @@ class Deployment(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._id)
         return self._id.value
 
+    @property
+    def ref(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._ref)
+        return self._ref.value
+
     @property
     def url(self):
         """
@@ -157,27 +165,27 @@ class Deployment(github.GithubObject.CompletableGithubObject):
 
     def get_statuses(self):
         """
-        :calls: `GET /repos/:owner/deployments/:deployment_id/statuses <https://developer.github.com/v3/repos/deployments/#list-deployment-statuses>`_
+        :calls: `GET /repos/{owner}/deployments/{deployment_id}/statuses <https://docs.github.com/en/rest/reference/repos#list-deployments>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.DeploymentStatus.DeploymentStatus`
         """
         return github.PaginatedList.PaginatedList(
             github.DeploymentStatus.DeploymentStatus,
             self._requester,
-            self.url + "/statuses",
+            f"{self.url}/statuses",
             None,
             headers={"Accept": self._get_accept_header()},
         )
 
     def get_status(self, id_):
         """
-        :calls: `GET /repos/:owner/deployments/:deployment_id/statuses/:status_id  <https://developer.github.com/v3/repos/deployments/#get-a-deployment-status>`_
+        :calls: `GET /repos/{owner}/deployments/{deployment_id}/statuses/{status_id}  <https://docs.github.com/en/rest/reference/repos#get-a-deployment>`_
         :param id_: int
         :rtype: :class:`github.DeploymentStatus.DeploymentStatus`
         """
         assert isinstance(id_, int), id_
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
-            self.url + "/statuses/" + str(id_),
+            f"{self.url}/statuses/{id_}",
             headers={"Accept": self._get_accept_header()},
         )
         return github.DeploymentStatus.DeploymentStatus(
@@ -194,7 +202,7 @@ class Deployment(github.GithubObject.CompletableGithubObject):
         auto_inactive=github.GithubObject.NotSet,
     ):
         """
-        :calls: `POST /repos/:owner/:repo/deployments/:deployment_id/statuses <https://developer.github.com/v3/repos/deployments/#create-a-deployment-status>`_
+        :calls: `POST /repos/{owner}/{repo}/deployments/{deployment_id}/statuses <https://docs.github.com/en/rest/reference/repos#create-a-deployment-status>`_
         :param: state: string
         :param: target_url: string
         :param: description: string
@@ -234,7 +242,7 @@ class Deployment(github.GithubObject.CompletableGithubObject):
 
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
-            self.url + "/statuses",
+            f"{self.url}/statuses",
             input=post_parameters,
             headers={"Accept": self._get_accept_header()},
         )
@@ -254,6 +262,7 @@ class Deployment(github.GithubObject.CompletableGithubObject):
     def _initAttributes(self):
         self._id = github.GithubObject.NotSet
         self._production_environment = github.GithubObject.NotSet
+        self._ref = github.GithubObject.NotSet
         self._transient_environment = github.GithubObject.NotSet
         self._url = github.GithubObject.NotSet
         self._sha = github.GithubObject.NotSet
@@ -275,6 +284,8 @@ class Deployment(github.GithubObject.CompletableGithubObject):
             self._production_environment = self._makeBoolAttribute(
                 attributes["production_environment"]
             )
+        if "ref" in attributes:  # pragma no branch
+            self._ref = self._makeStringAttribute(attributes["ref"])
         if "transient_environment" in attributes:  # pragma no branch
             self._transient_environment = self._makeBoolAttribute(
                 attributes["transient_environment"]
