@@ -41,7 +41,7 @@ import github.PaginatedList
 
 class Gist(github.GithubObject.CompletableGithubObject):
     """
-    This class represents Gists. The reference can be found here https://developer.github.com/v3/gists/
+    This class represents Gists. The reference can be found here https://docs.github.com/en/rest/reference/gists
     """
 
     def __repr__(self):
@@ -201,7 +201,7 @@ class Gist(github.GithubObject.CompletableGithubObject):
 
     def create_comment(self, body):
         """
-        :calls: `POST /gists/:gist_id/comments <http://developer.github.com/v3/gists/comments>`_
+        :calls: `POST /gists/{gist_id}/comments <https://docs.github.com/en/rest/reference/gists#comments>`_
         :param body: string
         :rtype: :class:`github.GistComment.GistComment`
         """
@@ -210,7 +210,7 @@ class Gist(github.GithubObject.CompletableGithubObject):
             "body": body,
         }
         headers, data = self._requester.requestJsonAndCheck(
-            "POST", self.url + "/comments", input=post_parameters
+            "POST", f"{self.url}/comments", input=post_parameters
         )
         return github.GistComment.GistComment(
             self._requester, headers, data, completed=True
@@ -218,15 +218,15 @@ class Gist(github.GithubObject.CompletableGithubObject):
 
     def create_fork(self):
         """
-        :calls: `POST /gists/:id/forks <http://developer.github.com/v3/gists>`_
+        :calls: `POST /gists/{id}/forks <https://docs.github.com/en/rest/reference/gists>`_
         :rtype: :class:`github.Gist.Gist`
         """
-        headers, data = self._requester.requestJsonAndCheck("POST", self.url + "/forks")
+        headers, data = self._requester.requestJsonAndCheck("POST", f"{self.url}/forks")
         return Gist(self._requester, headers, data, completed=True)
 
     def delete(self):
         """
-        :calls: `DELETE /gists/:id <http://developer.github.com/v3/gists>`_
+        :calls: `DELETE /gists/{id} <https://docs.github.com/en/rest/reference/gists>`_
         :rtype: None
         """
         headers, data = self._requester.requestJsonAndCheck("DELETE", self.url)
@@ -235,7 +235,7 @@ class Gist(github.GithubObject.CompletableGithubObject):
         self, description=github.GithubObject.NotSet, files=github.GithubObject.NotSet
     ):
         """
-        :calls: `PATCH /gists/:id <http://developer.github.com/v3/gists>`_
+        :calls: `PATCH /gists/{id} <https://docs.github.com/en/rest/reference/gists>`_
         :param description: string
         :param files: dict of string to :class:`github.InputFileContent.InputFileContent`
         :rtype: None
@@ -262,13 +262,13 @@ class Gist(github.GithubObject.CompletableGithubObject):
 
     def get_comment(self, id):
         """
-        :calls: `GET /gists/:gist_id/comments/:id <http://developer.github.com/v3/gists/comments>`_
+        :calls: `GET /gists/{gist_id}/comments/{id} <https://docs.github.com/en/rest/reference/gists#comments>`_
         :param id: integer
         :rtype: :class:`github.GistComment.GistComment`
         """
         assert isinstance(id, int), id
         headers, data = self._requester.requestJsonAndCheck(
-            "GET", self.url + "/comments/" + str(id)
+            "GET", f"{self.url}/comments/{id}"
         )
         return github.GistComment.GistComment(
             self._requester, headers, data, completed=True
@@ -276,39 +276,39 @@ class Gist(github.GithubObject.CompletableGithubObject):
 
     def get_comments(self):
         """
-        :calls: `GET /gists/:gist_id/comments <http://developer.github.com/v3/gists/comments>`_
+        :calls: `GET /gists/{gist_id}/comments <https://docs.github.com/en/rest/reference/gists#comments>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.GistComment.GistComment`
         """
         return github.PaginatedList.PaginatedList(
             github.GistComment.GistComment,
             self._requester,
-            self.url + "/comments",
+            f"{self.url}/comments",
             None,
         )
 
     def is_starred(self):
         """
-        :calls: `GET /gists/:id/star <http://developer.github.com/v3/gists>`_
+        :calls: `GET /gists/{id}/star <https://docs.github.com/en/rest/reference/gists>`_
         :rtype: bool
         """
-        status, headers, data = self._requester.requestJson("GET", self.url + "/star")
+        status, headers, data = self._requester.requestJson("GET", f"{self.url}/star")
         return status == 204
 
     def reset_starred(self):
         """
-        :calls: `DELETE /gists/:id/star <http://developer.github.com/v3/gists>`_
+        :calls: `DELETE /gists/{id}/star <https://docs.github.com/en/rest/reference/gists>`_
         :rtype: None
         """
         headers, data = self._requester.requestJsonAndCheck(
-            "DELETE", self.url + "/star"
+            "DELETE", f"{self.url}/star"
         )
 
     def set_starred(self):
         """
-        :calls: `PUT /gists/:id/star <http://developer.github.com/v3/gists>`_
+        :calls: `PUT /gists/{id}/star <https://docs.github.com/en/rest/reference/gists>`_
         :rtype: None
         """
-        headers, data = self._requester.requestJsonAndCheck("PUT", self.url + "/star")
+        headers, data = self._requester.requestJsonAndCheck("PUT", f"{self.url}/star")
 
     def _initAttributes(self):
         self._comments = github.GithubObject.NotSet
