@@ -333,6 +333,7 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
         self._target_commitish = github.GithubObject.NotSet
         self._draft = github.GithubObject.NotSet
         self._prerelease = github.GithubObject.NotSet
+        self._generate_release_notes = github.GithubObject.NotSet
         self._author = github.GithubObject.NotSet
         self._url = github.GithubObject.NotSet
         self._upload_url = github.GithubObject.NotSet
@@ -360,6 +361,10 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
             self._draft = self._makeBoolAttribute(attributes["draft"])
         if "prerelease" in attributes:
             self._prerelease = self._makeBoolAttribute(attributes["prerelease"])
+        if "generate_release_notes" in attributes:
+            self._generate_release_notes = self._makeBoolAttribute(
+                attributes["generate_release_notes"]
+            )
         if "author" in attributes:
             self._author = self._makeClassAttribute(
                 github.NamedUser.NamedUser, attributes["author"]
