@@ -222,6 +222,14 @@ class Issue(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._state)
         return self._state.value
 
+    @property
+    def state_reason(self):
+        """
+        :type: string
+        """
+        self._completeIfNotSet(self._state_reason)
+        return self._state_reason.value
+
     @property
     def title(self):
         """
@@ -357,16 +365,18 @@ class Issue(github.GithubObject.CompletableGithubObject):
         milestone=github.GithubObject.NotSet,
         labels=github.GithubObject.NotSet,
         assignees=github.GithubObject.NotSet,
+        state_reason=github.GithubObject.NotSet,
     ):
         """
         :calls: `PATCH /repos/{owner}/{repo}/issues/{number} <https://docs.github.com/en/rest/reference/issues>`_
         :param title: string
         :param body: string
         :param assignee: string or :class:`github.NamedUser.NamedUser` or None
-        :param assignees: list of string or :class:`github.NamedUser.NamedUser`
         :param state: string
         :param milestone: :class:`github.Milestone.Milestone` or None
         :param labels: list of string
+        :param assignees: list of string or :class:`github.NamedUser.NamedUser`
+        :param state_reason: string
         :rtype: None
         """
         assert title is github.GithubObject.NotSet or isinstance(title, str), title
@@ -409,6 +419,8 @@ class Issue(github.GithubObject.CompletableGithubObject):
             ]
         if state is not github.GithubObject.NotSet:
             post_parameters["state"] = state
+        if state_reason is not github.GithubObject.NotSet:
+            post_parameters["state_reason"] = state_reason
         if milestone is not github.GithubObject.NotSet:
             post_parameters["milestone"] = milestone._identity if milestone else ""
         if labels is not github.GithubObject.NotSet:
@@ -636,6 +648,7 @@ class Issue(github.GithubObject.CompletableGithubObject):
         self._pull_request = github.GithubObject.NotSet
         self._repository = github.GithubObject.NotSet
         self._state = github.GithubObject.NotSet
+        self._state_reason = github.GithubObject.NotSet
         self._title = github.GithubObject.NotSet
         self._updated_at = github.GithubObject.NotSet
         self._url = github.GithubObject.NotSet
@@ -707,6 +720,8 @@ class Issue(github.GithubObject.CompletableGithubObject):
             )
         if "state" in attributes:  # pragma no branch
             self._state = self._makeStringAttribute(attributes["state"])
+        if "state_reason" in attributes:  # pragma no branch
+            self._state_reason = self._makeStringAttribute(attributes["state_reason"])
         if "title" in attributes:  # pragma no branch
             self._title = self._makeStringAttribute(attributes["title"])
         if "updated_at" in attributes:  # pragma no branch
