@@ -50,8 +50,7 @@
 #                                                                              #
 ################################################################################
 
-import base64
-import datetime
+import io
 import json
 import logging
 import mimetypes
@@ -59,11 +58,37 @@ import os
 import re
 import time
 import urllib
+import urllib.parse
 from io import IOBase
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    Generic,
+    ItemsView,
+    List,
+    Optional,
+    Tuple,
+    Type,
+    TypeVar,
+    Union,
+)
 
 import requests
+import requests.adapters
+from urllib3 import Retry
 
-from . import Consts, GithubException, GithubIntegration
+import github.Consts as Consts
+import github.GithubException as GithubException
+
+if TYPE_CHECKING:
+    from .AppAuthentication import AppAuthentication
+    from .Auth import Auth
+    from .GithubObject import GithubObject
+    from .InstallationAuthorization import InstallationAuthorization
+
+T = TypeVar("T")
 
 # For App authentication, time remaining before token expiration to request a new one
 ACCESS_TOKEN_REFRESH_THRESHOLD_SECONDS = 20
@@ -71,29 +96,31 @@ ACCESS_TOKEN_REFRESH_THRESHOLD_SECONDS = 20
 
 class RequestsResponse:
     # mimic the httplib response object
-    def __init__(self, r):
+    def __init__(self, r: requests.Response):
         self.status = r.status_code
         self.headers = r.headers
         self.text = r.text
 
-    def getheaders(self):
+    def getheaders(self) -> ItemsView[str, str]:
         return self.headers.items()
 
-    def read(self):
+    def read(self) -> str:
         return self.text
 
 
 class HTTPSRequestsConnectionClass:
+    retry: Union[int, Retry]
+
     # mimic the httplib connection object
     def __init__(
         self,
         host,
-        port=None,
-        strict=False,
-        timeout=None,
-        retry=None,
-        pool_size=None,
-        **kwargs,
+        port: Optional[int] = None,
+        strict: bool = False,
+        timeout: Optional[int] = None,
+        retry: Optional[Union[int, Retry]] = None,
+        pool_size: Optional[int] = None,
+        **kwargs: Any,
     ):
         self.port = port if port else 443
         self.host = host
@@ -119,13 +146,19 @@ class HTTPSRequestsConnectionClass:
         )
         self.session.mount("https://", self.adapter)
 
-    def request(self, verb, url, input, headers):
+    def request(
+        self,
+        verb: str,
+        url: str,
+        input: Optional[Union[str, io.BufferedReader]],
+        headers: Dict[str, str],
+    ):
         self.verb = verb
         self.url = url
         self.input = input
         self.headers = headers
 
-    def getresponse(self):
+    def getresponse(self) -> RequestsResponse:
         verb = getattr(self.session, self.verb.lower())
         url = f"{self.protocol}://{self.host}:{self.port}{self.url}"
         r = verb(
@@ -146,13 +179,13 @@ class HTTPRequestsConnectionClass:
     # mimic the httplib connection object
     def __init__(
         self,
-        host,
-        port=None,
-        strict=False,
-        timeout=None,
-        retry=None,
-        pool_size=None,
-        **kwargs,
+        host: str,
+        port: Optional[int] = None,
+        strict: bool = False,
+        timeout: Optional[int] = None,
+        retry: Optional[Union[int, Retry]] = None,
+        pool_size: Optional[int] = None,
+        **kwargs: Any,
     ):
         self.port = port if port else 80
         self.host = host
@@ -164,7 +197,7 @@ class HTTPRequestsConnectionClass:
         if retry is None:
             self.retry = requests.adapters.DEFAULT_RETRIES
         else:
-            self.retry = retry
+            self.retry = retry  # type: ignore
 
         if pool_size is None:
             self.pool_size = requests.adapters.DEFAULT_POOLSIZE
@@ -178,13 +211,13 @@ class HTTPRequestsConnectionClass:
         )
         self.session.mount("http://", self.adapter)
 
-    def request(self, verb, url, input, headers):
+    def request(self, verb: str, url: str, input: None, headers: Dict[str, str]):
         self.verb = verb
         self.url = url
         self.input = input
         self.headers = headers
 
-    def getresponse(self):
+    def getresponse(self) -> RequestsResponse:
         verb = getattr(self.session, self.verb.lower())
         url = f"{self.protocol}://{self.host}:{self.port}{self.url}"
         r = verb(
@@ -197,25 +230,34 @@ class HTTPRequestsConnectionClass:
         )
         return RequestsResponse(r)
 
-    def close(self):
+    def close(self) -> None:
         return
 
 
 class Requester:
+    __installation_authorization: Optional["InstallationAuthorization"]
+    __app_auth: Optional["AppAuthentication"]
+
     __httpConnectionClass = HTTPRequestsConnectionClass
     __httpsConnectionClass = HTTPSRequestsConnectionClass
     __connection = None
     __persist = True
     __logger = None
 
+    _frameBuffer: List[Any]
+
     @classmethod
-    def injectConnectionClasses(cls, httpConnectionClass, httpsConnectionClass):
+    def injectConnectionClasses(
+        cls,
+        httpConnectionClass: Type[HTTPRequestsConnectionClass],
+        httpsConnectionClass: Type[HTTPSRequestsConnectionClass],
+    ):
         cls.__persist = False
         cls.__httpConnectionClass = httpConnectionClass
         cls.__httpsConnectionClass = httpsConnectionClass
 
     @classmethod
-    def resetConnectionClasses(cls):
+    def resetConnectionClasses(cls) -> None:
         cls.__persist = True
         cls.__httpConnectionClass = HTTPRequestsConnectionClass
         cls.__httpsConnectionClass = HTTPSRequestsConnectionClass
@@ -231,11 +273,11 @@ class Requester:
     #############################################################
     # For Debug
     @classmethod
-    def setDebugFlag(cls, flag):
+    def setDebugFlag(cls, flag: bool) -> None:
         cls.DEBUG_FLAG = flag
 
     @classmethod
-    def setOnCheckMe(cls, onCheckMe):
+    def setOnCheckMe(cls, onCheckMe: Callable) -> None:
         cls.ON_CHECK_ME = onCheckMe
 
     DEBUG_FLAG = False
@@ -244,9 +286,9 @@ class Requester:
 
     DEBUG_HEADER_KEY = "DEBUG_FRAME"
 
-    ON_CHECK_ME = None
+    ON_CHECK_ME: Optional[Callable] = None
 
-    def NEW_DEBUG_FRAME(self, requestHeader):
+    def NEW_DEBUG_FRAME(self, requestHeader: Dict[str, str]) -> None:
         """
         Initialize a debug frame with requestHeader
         Frame count is updated and will be attached to respond header
@@ -264,7 +306,9 @@ class Requester:
 
             self._frameCount = len(self._frameBuffer) - 1
 
-    def DEBUG_ON_RESPONSE(self, statusCode, responseHeader, data):
+    def DEBUG_ON_RESPONSE(
+        self, statusCode: int, responseHeader: Dict[str, Union[str, int]], data: str
+    ):
         """
         Update current frame with response
         Current frame index will be attached to responseHeader
@@ -277,14 +321,14 @@ class Requester:
             ]
             responseHeader[self.DEBUG_HEADER_KEY] = self._frameCount
 
-    def check_me(self, obj):
+    def check_me(self, obj: "GithubObject"):
         if (
             self.DEBUG_FLAG and self.ON_CHECK_ME is not None
         ):  # pragma no branch (Flag always set in tests)
             frame = None
             if self.DEBUG_HEADER_KEY in obj._headers:
                 frame_index = obj._headers[self.DEBUG_HEADER_KEY]
-                frame = self._frameBuffer[frame_index]
+                frame = self._frameBuffer[frame_index]  # type: ignore
             self.ON_CHECK_ME(obj, frame)
 
     def _initializeDebugFeature(self):
@@ -293,46 +337,32 @@ class Requester:
 
     #############################################################
 
+    _frameCount: int
+    __connectionClass: Union[
+        Type[HTTPRequestsConnectionClass], Type[HTTPSRequestsConnectionClass]
+    ]
+    __hostname: str
+    __authorizationHeader: Optional[str]
+
+    # keep arguments in-sync with github.MainClass and GithubIntegration
     def __init__(
         self,
-        login_or_token,
-        password,
-        jwt,
-        app_auth,
-        base_url,
-        timeout,
-        user_agent,
-        per_page,
-        verify,
-        retry,
-        pool_size,
+        auth: Optional["Auth"],
+        base_url: str,
+        timeout: int,
+        user_agent: str,
+        per_page: int,
+        verify: Union[bool, str],
+        retry: Optional[Union[int, Retry]],
+        pool_size: Optional[int],
     ):
         self._initializeDebugFeature()
 
-        self.__installation_authorization = None
-        self.__app_auth = app_auth
+        self.__auth = auth
         self.__base_url = base_url
 
-        if password is not None:
-            login = login_or_token
-            b64 = (
-                base64.b64encode((f"{login}:{password}").encode())
-                .decode("utf-8")
-                .replace("\n", "")
-            )
-            self.__authorizationHeader = f"Basic {b64}"
-        elif login_or_token is not None:
-            token = login_or_token
-            self.__authorizationHeader = f"token {token}"
-        elif jwt is not None:
-            self.__authorizationHeader = f"Bearer {jwt}"
-        elif self.__app_auth is not None:
-            self._refresh_token()
-        else:
-            self.__authorizationHeader = None
-
         o = urllib.parse.urlparse(base_url)
-        self.__hostname = o.hostname
+        self.__hostname = o.hostname  # type: ignore
         self.__port = o.port
         self.__prefix = o.path
         self.__timeout = timeout
@@ -359,42 +389,56 @@ class Requester:
         self.__userAgent = user_agent
         self.__verify = verify
 
-    def _must_refresh_token(self) -> bool:
-        """Check if it is time to refresh the API token gotten from the GitHub app installation"""
-        if not self.__installation_authorization:
-            return False
-        return (
-            self.__installation_authorization.expires_at
-            < datetime.datetime.utcnow()
-            + datetime.timedelta(seconds=ACCESS_TOKEN_REFRESH_THRESHOLD_SECONDS)
-        )
+        self.__installation_authorization = None
 
-    def _get_installation_authorization(self):
-        assert self.__app_auth is not None
-        integration = GithubIntegration.GithubIntegration(
-            self.__app_auth.app_id,
-            self.__app_auth.private_key,
+        # provide auth implementations that require a requester with this requester
+        if isinstance(self.__auth, WithRequester):
+            self.__auth.withRequester(self)
+
+    @property
+    def kwargs(self):
+        """
+        Returns arguments required to recreate this Requester with Requester.__init__, as well as
+        with MainClass.__init__ and GithubIntegration.__init__.
+        :return:
+        """
+        return dict(
+            auth=self.__auth,
             base_url=self.__base_url,
-        )
-        return integration.get_access_token(
-            self.__app_auth.installation_id,
-            permissions=self.__app_auth.token_permissions,
+            timeout=self.__timeout,
+            user_agent=self.__userAgent,
+            per_page=self.per_page,
+            verify=self.__verify,
+            retry=self.__retry,
+            pool_size=self.__pool_size,
         )
 
-    def _refresh_token_if_needed(self) -> None:
-        """Get a new access token from the GitHub app installation if the one we have is about to expire"""
-        if not self.__installation_authorization:
-            return
-        if self._must_refresh_token():
-            logging.debug("Refreshing access token")
-            self._refresh_token()
+    @property
+    def base_url(self) -> str:
+        return self.__base_url
 
-    def _refresh_token(self) -> None:
-        """In the context of a GitHub app, refresh the access token"""
-        self.__installation_authorization = self._get_installation_authorization()
-        self.__authorizationHeader = f"token {self.__installation_authorization.token}"
+    @property
+    def auth(self) -> Optional["Auth"]:
+        return self.__auth
 
-    def requestJsonAndCheck(self, verb, url, parameters=None, headers=None, input=None):
+    def withAuth(self, auth: Optional["Auth"]) -> "Requester":
+        """
+        Create a new requester instance with identical configuration but the given authentication method.
+        :param auth: authentication method
+        :return: new Requester implementation
+        """
+        kwargs = self.kwargs
+        kwargs.update(auth=auth)
+        return Requester(**kwargs)
+
+    def requestJsonAndCheck(
+        self,
+        verb: str,
+        url: str,
+        parameters: Optional[Dict[str, Any]] = None,
+        headers: Optional[Dict[str, str]] = None,
+        input: Optional[Any] = None,
+    ) -> Tuple[Dict[str, Any], Any]:
         return self.__check(
             *self.requestJson(
                 verb, url, parameters, headers, input, self.__customConnection(url)
@@ -402,29 +446,53 @@ class Requester:
         )
 
     def requestMultipartAndCheck(
-        self, verb, url, parameters=None, headers=None, input=None
-    ):
+        self,
+        verb: str,
+        url: str,
+        parameters: Optional[Dict[str, Any]] = None,
+        headers: Optional[Dict[str, Any]] = None,
+        input: Optional[Dict[str, str]] = None,
+    ) -> Tuple[Dict[str, Any], Optional[Dict[str, Any]]]:
         return self.__check(
             *self.requestMultipart(
                 verb, url, parameters, headers, input, self.__customConnection(url)
             )
         )
 
-    def requestBlobAndCheck(self, verb, url, parameters=None, headers=None, input=None):
+    def requestBlobAndCheck(
+        self,
+        verb: str,
+        url: str,
+        parameters: Optional[Dict[str, str]] = None,
+        headers: Optional[Dict[str, str]] = None,
+        input: Optional[str] = None,
+        cnx: Optional[
+            Union[HTTPRequestsConnectionClass, HTTPSRequestsConnectionClass]
+        ] = None,
+    ) -> Tuple[Dict[str, Any], Dict[str, Any]]:
         return self.__check(
             *self.requestBlob(
                 verb, url, parameters, headers, input, self.__customConnection(url)
             )
         )
 
-    def __check(self, status, responseHeaders, output):
-        output = self.__structuredFromJson(output)
+    def __check(
+        self,
+        status: int,
+        responseHeaders: Dict[str, Any],
+        output: str,
+    ) -> Tuple[Dict[str, Any], Any]:
+        data = self.__structuredFromJson(output)
         if status >= 400:
-            raise self.__createException(status, responseHeaders, output)
-        return responseHeaders, output
+            raise self.__createException(status, responseHeaders, data)
+        return responseHeaders, data
 
-    def __customConnection(self, url):
-        cnx = None
+    def __customConnection(
+        self, url: str
+    ) -> Optional[Union[HTTPRequestsConnectionClass, HTTPSRequestsConnectionClass]]:
+        cnx: Optional[
+            Union[HTTPRequestsConnectionClass, HTTPSRequestsConnectionClass]
+        ] = None
         if not url.startswith("/"):
             o = urllib.parse.urlparse(url)
             if (
@@ -437,7 +505,7 @@ class Requester:
             ):  # issue80
                 if o.scheme == "http":
                     cnx = self.__httpConnectionClass(
-                        o.hostname,
+                        o.hostname,  # type: ignore
                         o.port,
                         retry=self.__retry,
                         pool_size=self.__pool_size,
@@ -451,8 +519,16 @@ class Requester:
                     )
         return cnx
 
-    def __createException(self, status, headers, output):
-        if status == 401 and output.get("message") == "Bad credentials":
+    def __createException(
+        self,
+        status: int,
+        headers: Dict[str, Any],
+        output: Dict[str, Any],
+    ) -> Any:
+        message = output.get("message", "").lower() if output is not None else ""
+
+        cls = GithubException.GithubException
+        if status == 401 and message == "bad credentials":
             cls = GithubException.BadCredentialsException
         elif (
             status == 401
@@ -460,24 +536,21 @@ class Requester:
             and re.match(r".*required.*", headers[Consts.headerOTP])
         ):
             cls = GithubException.TwoFactorException
-        elif status == 403 and output.get("message").startswith(
-            "Missing or invalid User Agent string"
+        elif status == 403 and message.startswith(
+            "missing or invalid user agent string"
         ):
             cls = GithubException.BadUserAgentException
         elif status == 403 and (
-            output.get("message").lower().startswith("api rate limit exceeded")
-            or output.get("message")
-            .lower()
-            .endswith("please wait a few minutes before you try again.")
+            message.startswith("api rate limit exceeded")
+            or message.endswith("please wait a few minutes before you try again.")
         ):
             cls = GithubException.RateLimitExceededException
-        elif status == 404 and output.get("message") == "Not Found":
+        elif status == 404 and message == "not found":
             cls = GithubException.UnknownObjectException
-        else:
-            cls = GithubException.GithubException
+
         return cls(status, output, headers)
 
-    def __structuredFromJson(self, data):
+    def __structuredFromJson(self, data: str) -> Any:
         if len(data) == 0:
             return None
         else:
@@ -491,16 +564,32 @@ class Requester:
                 return {"data": data}
 
     def requestJson(
-        self, verb, url, parameters=None, headers=None, input=None, cnx=None
-    ):
+        self,
+        verb: str,
+        url: str,
+        parameters: Optional[Dict[str, Any]] = None,
+        headers: Optional[Dict[str, Any]] = None,
+        input: Optional[Any] = None,
+        cnx: Optional[
+            Union[HTTPRequestsConnectionClass, HTTPSRequestsConnectionClass]
+        ] = None,
+    ) -> Tuple[int, Dict[str, Any], str]:
         def encode(input):
             return "application/json", json.dumps(input)
 
         return self.__requestEncode(cnx, verb, url, parameters, headers, input, encode)
 
     def requestMultipart(
-        self, verb, url, parameters=None, headers=None, input=None, cnx=None
-    ):
+        self,
+        verb: str,
+        url: str,
+        parameters: Optional[Dict[str, Any]] = None,
+        headers: Optional[Dict[str, Any]] = None,
+        input: Optional[Dict[str, str]] = None,
+        cnx: Optional[
+            Union[HTTPRequestsConnectionClass, HTTPSRequestsConnectionClass]
+        ] = None,
+    ) -> Tuple[int, Dict[str, Any], str]:
         def encode(input):
             boundary = "----------------------------3c3ba8b523b2"
             eol = "\r\n"
@@ -516,12 +605,25 @@ class Requester:
 
         return self.__requestEncode(cnx, verb, url, parameters, headers, input, encode)
 
-    def requestBlob(self, verb, url, parameters={}, headers={}, input=None, cnx=None):
-        def encode(local_path):
-            if "Content-Type" in headers:
-                mime_type = headers["Content-Type"]
+    def requestBlob(
+        self,
+        verb: str,
+        url: str,
+        parameters: Optional[Dict[str, str]] = None,
+        headers: Optional[Dict[str, str]] = None,
+        input: Optional[str] = None,
+        cnx: Optional[
+            Union[HTTPRequestsConnectionClass, HTTPSRequestsConnectionClass]
+        ] = None,
+    ) -> Tuple[int, Dict[str, Any], str]:
+        if headers is None:
+            headers = {}
+
+        def encode(local_path: str):
+            if "Content-Type" in headers:  # type: ignore
+                mime_type = headers["Content-Type"]  # type: ignore
             else:
-                guessed_type = mimetypes.guess_type(input)
+                guessed_type = mimetypes.guess_type(local_path)
                 mime_type = (
                     guessed_type[0]
                     if guessed_type[0] is not None
@@ -550,15 +652,25 @@ class Requester:
         )
 
     def __requestEncode(
-        self, cnx, verb, url, parameters, requestHeaders, input, encode
-    ):
+        self,
+        cnx: Optional[Union[HTTPRequestsConnectionClass, HTTPSRequestsConnectionClass]],
+        verb: str,
+        url: str,
+        parameters: Optional[Dict[str, str]],
+        requestHeaders: Optional[Dict[str, str]],
+        input: Optional[T],
+        encode: Callable[[T], Tuple[str, Any]],
+    ) -> Tuple[int, Dict[str, Any], str]:
         assert verb in ["HEAD", "GET", "POST", "PATCH", "PUT", "DELETE"]
         if parameters is None:
-            parameters = dict()
+            parameters = {}
         if requestHeaders is None:
-            requestHeaders = dict()
+            requestHeaders = {}
 
-        self.__authenticate(url, requestHeaders, parameters)
+        if self.__auth is not None:
+            requestHeaders[
+                "Authorization"
+            ] = f"{self.__auth.token_type} {self.__auth.token}"
         requestHeaders["User-Agent"] = self.__userAgent
 
         url = self.__makeAbsoluteUrl(url)
@@ -579,11 +691,15 @@ class Requester:
             and Consts.headerRateLimit in responseHeaders
         ):
             self.rate_limiting = (
-                int(responseHeaders[Consts.headerRateRemaining]),
-                int(responseHeaders[Consts.headerRateLimit]),
+                # ints expected but sometimes floats returned: https://github.com/PyGithub/PyGithub/pull/2697
+                int(float(responseHeaders[Consts.headerRateRemaining])),
+                int(float(responseHeaders[Consts.headerRateLimit])),
             )
         if Consts.headerRateReset in responseHeaders:
-            self.rate_limiting_resettime = int(responseHeaders[Consts.headerRateReset])
+            # ints expected but sometimes floats returned: https://github.com/PyGithub/PyGithub/pull/2697
+            self.rate_limiting_resettime = int(
+                float(responseHeaders[Consts.headerRateReset])
+            )
 
         if Consts.headerOAuthScopes in responseHeaders:
             self.oauth_scopes = responseHeaders[Consts.headerOAuthScopes].split(", ")
@@ -592,7 +708,14 @@ class Requester:
 
         return status, responseHeaders, output
 
-    def __requestRaw(self, cnx, verb, url, requestHeaders, input):
+    def __requestRaw(
+        self,
+        cnx: Optional[Union[HTTPRequestsConnectionClass, HTTPSRequestsConnectionClass]],
+        verb: str,
+        url: str,
+        requestHeaders: Dict[str, str],
+        input: Optional[Any],
+    ) -> Tuple[int, Dict[str, Any], str]:
         original_cnx = cnx
         if cnx is None:
             cnx = self.__createConnection()
@@ -617,17 +740,35 @@ class Requester:
             return self.__requestRaw(original_cnx, verb, url, requestHeaders, input)
 
         if status == 301 and "location" in responseHeaders:
-            o = urllib.parse.urlparse(responseHeaders["location"])
+            location = responseHeaders["location"]
+            o = urllib.parse.urlparse(location)
+            if o.scheme != self.__scheme:
+                raise RuntimeError(
+                    f"Github server redirected from {self.__scheme} protocol to {o.scheme}, "
+                    f"please correct your Github server URL via base_url: Github(base_url=...)"
+                )
+            if o.hostname != self.__hostname:
+                raise RuntimeError(
+                    f"Github server redirected from host {self.__hostname} to {o.hostname}, "
+                    f"please correct your Github server URL via base_url: Github(base_url=...)"
+                )
+            if o.path == url:
+                port = ":" + str(self.__port) if self.__port is not None else ""
+                requested_location = f"{self.__scheme}://{self.__hostname}{port}{url}"
+                raise RuntimeError(
+                    f"Requested {requested_location} but server redirected to {location}, "
+                    f"you may need to correct your Github server URL "
+                    f"via base_url: Github(base_url=...)"
+                )
+            if self._logger.isEnabledFor(logging.INFO):
+                self._logger.info(
+                    f"Following Github server redirection from {url} to {o.path}"
+                )
             return self.__requestRaw(original_cnx, verb, o.path, requestHeaders, input)
 
         return status, responseHeaders, output
 
-    def __authenticate(self, url, requestHeaders, parameters):
-        self._refresh_token_if_needed()
-        if self.__authorizationHeader is not None:
-            requestHeaders["Authorization"] = self.__authorizationHeader
-
-    def __makeAbsoluteUrl(self, url):
+    def __makeAbsoluteUrl(self, url: str) -> str:
         # URLs generated locally will be relative to __base_url
         # URLs returned from the server will start with __base_url
         if url.startswith("/"):
@@ -647,17 +788,19 @@ class Requester:
                 url += f"?{o.query}"
         return url
 
-    def __addParametersToUrl(self, url, parameters):
+    def __addParametersToUrl(
+        self,
+        url: str,
+        parameters: Dict[str, Any],
+    ):
         if len(parameters) == 0:
             return url
         else:
             return f"{url}?{urllib.parse.urlencode(parameters)}"
 
-    def __createConnection(self):
-        kwds = {}
-        kwds["timeout"] = self.__timeout
-        kwds["verify"] = self.__verify
-
+    def __createConnection(
+        self,
+    ) -> Union[HTTPRequestsConnectionClass, HTTPSRequestsConnectionClass]:
         if self.__persist and self.__connection is not None:
             return self.__connection
 
@@ -666,15 +809,29 @@ class Requester:
             self.__port,
             retry=self.__retry,
             pool_size=self.__pool_size,
-            **kwds,
+            timeout=self.__timeout,
+            verify=self.__verify,
         )
 
         return self.__connection
 
-    def __log(self, verb, url, requestHeaders, input, status, responseHeaders, output):
+    @property
+    def _logger(self) -> logging.Logger:
         if self.__logger is None:
             self.__logger = logging.getLogger(__name__)
-        if self.__logger.isEnabledFor(logging.DEBUG):
+        return self.__logger
+
+    def __log(
+        self,
+        verb: str,
+        url: str,
+        requestHeaders: Dict[str, str],
+        input: Optional[Any],
+        status: Optional[int],
+        responseHeaders: Dict[str, Any],
+        output: Optional[str],
+    ) -> None:
+        if self._logger.isEnabledFor(logging.DEBUG):
             headersForRequest = requestHeaders.copy()
             if "Authorization" in requestHeaders:
                 if requestHeaders["Authorization"].startswith("Basic"):
@@ -689,7 +846,7 @@ class Requester:
                     headersForRequest[
                         "Authorization"
                     ] = "(unknown auth removed)"  # pragma no cover (Cannot happen, but could if we add an authentication method => be prepared)
-            self.__logger.debug(
+            self._logger.debug(
                 "%s %s://%s%s %s %s ==> %i %s %s",
                 verb,
                 self.__scheme,
@@ -701,3 +858,23 @@ class Requester:
                 responseHeaders,
                 output,
             )
+
+
+class WithRequester(Generic[T]):
+    """
+    Mixin class that allows to set a requester.
+    """
+
+    __requester: Requester
+
+    def __init__(self):
+        self.__requester: Optional[Requester] = None
+
+    @property
+    def requester(self) -> Requester:
+        return self.__requester
+
+    def withRequester(self, requester: Requester) -> "WithRequester[T]":
+        assert isinstance(requester, Requester), requester
+        self.__requester = requester
+        return self
